==> mobGameSDK-FT.2.4.3.AS-sources.jar: com/mobgame/utils/Utils.java <==
package com.mobgame.utils;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Locale;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Build;
import android.provider.Settings;
import android.text.TextUtils;
import android.util.Log;
import android.view.ContextThemeWrapper;

import com.mobgame.model.MUrl;

public class Utils {

	private static String TAG = Utils.class.getSimpleName();

	public static String getReferrer(Context c) {
		return Preference.getString(c, Constants.SHARED_PREF_REFERRER);
	}
	
	public static void setReferrer(Context c, String value) {
		Preference.save(c, Constants.SHARED_PREF_REFERRER, value);
	}
	
	public static String getGameVersion(Context c) {
		String versionName = null;
		final PackageManager packageManager = c.getPackageManager();
		if (packageManager != null) {
			try {
				PackageInfo packageInfo = packageManager.getPackageInfo(c.getPackageName(), 0);
				versionName = packageInfo.versionName;
			} catch (PackageManager.NameNotFoundException e) {
				versionName = null;
			}
		}
		return versionName;
	}
	
	public static String getGameVersionCode(Context c) {
		String versionCode = null;
		final PackageManager packageManager = c.getPackageManager();
		if (packageManager != null) {
			try {
				PackageInfo packageInfo = packageManager.getPackageInfo(c.getPackageName(), 0);
				versionCode = packageInfo.versionCode + "";
			} catch (PackageManager.NameNotFoundException e) {
				versionCode = null;
			}
		}
		return versionCode;
	}

	public static String getSDKVersion(Context c) {
		return Constants.SDK_VERSION;
	}
	
	public static String getNetwork(Context context) {
		try {
			ConnectivityManager manager = (ConnectivityManager) context.getSystemService(Context.CONNECTIVITY_SERVICE);
			NetworkInfo info = manager.getActiveNetworkInfo();
			if (info != null)
				return info.getTypeName();
		} catch (Exception e) {
			e.printStackTrace();
		}
		return "";
	}

	public static void addNtf(Context c, int id) {
		try {
			String ntfsString = Preference.getString(c, 
					Constants.SHARED_PREF_NOTIFICATONS);
			JSONArray ntfs = new JSONArray();
			try {
				ntfs = new JSONArray(ntfsString);
			} catch (JSONException e) {}
			ntfs.put(id);
			Preference.save(c, 
					Constants.SHARED_PREF_NOTIFICATONS, 
					ntfs.toString());
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public static void removeNtf(Context c, int id) {
		Log.d(TAG, "removeNotificationId" + id);
		try {
			String ntfsString = Preference.getString(c,
					Constants.SHARED_PREF_NOTIFICATONS);
			JSONArray ntfs = new JSONArray(ntfsString);
			JSONArray newNtfs = new JSONArray();
			for (int i = 0; i < ntfs.length(); i++) {
				if (id != ntfs.getInt(i)) {
					newNtfs.put(ntfs.getInt(i));
				}
			}
			Log.d(TAG, "left removeNotificationId" + newNtfs);
			Preference.save(c, 
					Constants.SHARED_PREF_NOTIFICATONS, 
					newNtfs.toString());
		} catch (JSONException e) {}
	}
	
	public static boolean hasNtf(Context c) {
		return !getNtfs(c).isEmpty();
	}

	public static boolean hasNtf(Context c, int id) {
		return getNtfs(c).contains(id);
	}

	public static ArrayList<Integer> getNtfs(Context c) {
		try {
			String ntfsString = Preference.getString(c,
					Constants.SHARED_PREF_NOTIFICATONS);
			JSONArray ntfs = new JSONArray(ntfsString);
			ArrayList<Integer> ntfIds = new ArrayList<Integer>();
			for (int i = ntfs.length() - 1; i >= 0; i--) {
				ntfIds.add(ntfs.getInt(i));
			}
			return ntfIds;
		} catch (JSONException e) {}
		return new ArrayList<Integer>();
	}

	public static int countNtfs(Context c) {
		try {
			return getNtfs(c).size();
		} catch (Exception e) {
			return 0;
		}
	}

	public static boolean isDashboardEnabled(Context c) {
		return Preference.getBoolean(c, 
				Constants.SHARED_PREF_DB_ENABLED, 
				false);
	}

	public static boolean isPlfUrl(MUrl url) {
		return isPlfUrl(url.getPath());
	}
	
	public static boolean isPlfUrl(String url) {
		String u = url.toLowerCase(Locale.ENGLISH);
		return u.startsWith("http://" + Constants.DOMAIN_NAME)
		|| u.startsWith("https://" + Constants.DOMAIN_NAME);
	}
	
	private static ProgressDialog progressDialog;
	
	public static void showLoading(Activity a, String message) {
		showLoading(a, null, message, true);
	}

	public static void showLoading(Activity a, String title, final String message){
		showLoading(a, null, message, true);
	}
	
	public static void showLoading(Activity a, String title, final String message, boolean cancelable) {
		hideLoading();
//		progressDialog = ProgressDialog.show(a, title, message + "    ");
		progressDialog = new ProgressDialog(getContextThemeWrapper(a));
		progressDialog.setMessage(message);
		progressDialog.setIndeterminateDrawable(null);
		progressDialog.setCancelable(cancelable);
		progressDialog.show();
	}
	
	public static void hideLoading() {
		if (progressDialog != null) {
			progressDialog.dismiss();
		}
	}
	
	public static ContextThemeWrapper getContextThemeWrapper(Context c) {
		if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.HONEYCOMB) {
			return new ContextThemeWrapper(c, android.R.style.Theme_Holo_Light_Dialog_NoActionBar);
		} else {
			return new ContextThemeWrapper(c, android.R.style.Theme_Light_NoTitleBar);
		}
	}

	public static String getSHACheckSum(String checksum) {
		try {
			MessageDigest md = MessageDigest.getInstance("SHA1");
			md.update(checksum.getBytes());
			byte byteData[] = md.digest();

			// convert the byte to hex format method 1
			StringBuffer sb = new StringBuffer();
			for (int i = 0; i < byteData.length; i++) {
				sb.append(Integer.toString((byteData[i] & 0xff) + 0x100, 16).substring(1));
			}
			return sb.toString();
		} catch (NoSuchAlgorithmException e) {
			e.printStackTrace();
			return null;
		}
	}

	public static boolean isJSONValid(String jsonString) {
		if (TextUtils.isEmpty(jsonString)) {
			return false;
		} else {
			try {
				new JSONObject(jsonString);
			} catch (JSONException ex) {
				return false;
			}
		}
		return true;
	}

	public static boolean canDrawOverApp(Context c) {
		if (Build.VERSION.SDK_INT >= 23) {
			try {
				Method m = Settings.class.getDeclaredMethod("canDrawOverlays", Context.class);
				m.setAccessible(true); //if security settings allow this
				Boolean o = (Boolean) m.invoke(null, c);
				return o;
			} catch (NoSuchMethodException e) {
				e.printStackTrace();
			} catch (IllegalAccessException e) {
				e.printStackTrace();
			} catch (IllegalArgumentException e) {
				e.printStackTrace();
			} catch (InvocationTargetException e) {
				e.printStackTrace();
			}
		}
		return true;
	}

	public static Bitmap drawableToBitmap(Drawable drawable) {
	    if (drawable instanceof BitmapDrawable) {
	        return ((BitmapDrawable)drawable).getBitmap();
	    }

	    int width = drawable.getIntrinsicWidth();
	    width = width > 0 ? width : 1;
	    int height = drawable.getIntrinsicHeight();
	    height = height > 0 ? height : 1;

	    Bitmap bitmap = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
	    Canvas canvas = new Canvas(bitmap); 
	    drawable.setBounds(0, 0, canvas.getWidth(), canvas.getHeight());
	    drawable.draw(canvas);

	    return bitmap;
	}
	public static boolean isOnline(Context context) {
	    ConnectivityManager cm = (ConnectivityManager) context
	            .getSystemService(Context.CONNECTIVITY_SERVICE);
	    NetworkInfo netInfo = cm.getActiveNetworkInfo();
	    return netInfo != null && netInfo.isConnectedOrConnecting();
	}
}

==> mobGameSDK-FT.2.4.4.1.AS-sources.jar: com/mobgame/utils/Utils.java <==
package com.mobgame.utils;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Locale;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Build;
import android.provider.Settings;
import android.text.TextUtils;
import android.util.Log;
import android.view.ContextThemeWrapper;

import com.mobgame.model.MUrl;

public class Utils {

	private static String TAG = Utils.class.getSimpleName();

	public static String getReferrer(Context c) {
		return Preference.getString(c, Constants.SHARED_PREF_REFERRER);
	}
	
	public static void setReferrer(Context c, String value) {
		Preference.save(c, Constants.SHARED_PREF_REFERRER, value);
	}
	
	public static String getGameVersion(Context c) {
		String versionName = null;
		final PackageManager packageManager = c.getPackageManager();
		if (packageManager != null) {
			try {
				PackageInfo packageInfo = packageManager.getPackageInfo(c.getPackageName(), 0);
				versionName = packageInfo.versionName;
			} catch (PackageManager.NameNotFoundException e) {
				versionName = null;
			}
		}
		return versionName;
	}
	
	public static String getGameVersionCode(Context c) {
		String versionCode = null;
		final PackageManager packageManager = c.getPackageManager();
		if (packageManager != null) {
			try {
				PackageInfo packageInfo = packageManager.getPackageInfo(c.getPackageName(), 0);
				versionCode = packageInfo.versionCode + "";
			} catch (PackageManager.NameNotFoundException e) {
				versionCode = null;
			}
		}
		return versionCode;
	}

	public static String getSDKVersion(Context c) {
		return Constants.SDK_VERSION;
	}
	
	public static String getNetwork(Context context) {
		try {
			ConnectivityManager manager = (ConnectivityManager) context.getSystemService(Context.CONNECTIVITY_SERVICE);
			NetworkInfo info = manager.getActiveNetworkInfo();
			if (info != null)
				return info.getTypeName();
		} catch (Exception e) {
			e.printStackTrace();
		}
		return "";
	}

	public static void addNtf(Context c, int id) {
		try {
			String ntfsString = Preference.getString(c, 
					Constants.SHARED_PREF_NOTIFICATONS);
			JSONArray ntfs = new JSONArray();
			try {
				ntfs = new JSONArray(ntfsString);
			} catch (JSONException e) {}
			ntfs.put(id);
			Preference.save(c, 
					Constants.SHARED_PREF_NOTIFICATONS, 
					ntfs.toString());
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public static void removeNtf(Context c, int id) {
		Log.d(TAG, "removeNotificationId" + id);
		try {
			String ntfsString = Preference.getString(c,
					Constants.SHARED_PREF_NOTIFICATONS);
			JSONArray ntfs = new JSONArray(ntfsString);
			JSONArray newNtfs = new JSONArray();
			for (int i = 0; i < ntfs.length(); i++) {
				if (id != ntfs.getInt(i)) {
					newNtfs.put(ntfs.getInt(i));
				}
			}
			Log.d(TAG, "left removeNotificationId" + newNtfs);
			Preference.save(c, 
					Constants.SHARED_PREF_NOTIFICATONS, 
					newNtfs.toString());
		} catch (JSONException e) {}
	}
	
	public static boolean hasNtf(Context c) {
		return !getNtfs(c).isEmpty();
	}

	public static boolean hasNtf(Context c, int id) {
		return getNtfs(c).contains(id);
	}

	public static ArrayList<Integer> getNtfs(Context c) {
		try {
			String ntfsString = Preference.getString(c,
					Constants.SHARED_PREF_NOTIFICATONS);
			JSONArray ntfs = new JSONArray(ntfsString);
			ArrayList<Integer> ntfIds = new ArrayList<Integer>();
			for (int i = ntfs.length() - 1; i >= 0; i--) {
				ntfIds.add(ntfs.getInt(i));
			}
			return ntfIds;
		} catch (JSONException e) {}
		return new ArrayList<Integer>();
	}

	public static int countNtfs(Context c) {
		try {
			return getNtfs(c).size();
		} catch (Exception e) {
			return 0;
		}
	}

	public static boolean isDashboardEnabled(Context c) {
		return Preference.getBoolean(c, 
				Constants.SHARED_PREF_DB_ENABLED, 
				false);
	}

//	public static boolean isFloatButtonEnabled(Context c) {
//		return Preference.getBoolean(c, 
//				Constants.SHARED_PREF_FLOATBUTTON_ENABLED, 
//				false);
//	}
	
	public static boolean isPlfUrl(MUrl url) {
		return isPlfUrl(url.getPath());
	}
	
	public static boolean isPlfUrl(String url) {
		String u = url.toLowerCase(Locale.ENGLISH);
		return u.startsWith("http://" + Constants.DOMAIN_NAME)
		|| u.startsWith("https://" + Constants.DOMAIN_NAME);
	}
	
	private static ProgressDialog progressDialog;
	
	public static void showLoading(Activity a, String message) {
		showLoading(a, null, message);
	}
//
	public static void showLoading(Activity a, String title, final String message){
		showLoading(a, null, message, true);
//		showLoading(a, null, message, false);
	}
	
	public static void showLoading(Activity a, String title, final String message, boolean cancelable) {
		hideLoading();
//		progressDialog = ProgressDialog.show(a, title, message + "    ");
		progressDialog = new ProgressDialog(getContextThemeWrapper(a));
		progressDialog.setMessage(message);
		progressDialog.setIndeterminateDrawable(null);
//		progressDialog.setCancelable(false);
		progressDialog.show();
	}
	
	public static void hideLoading() {
		if (progressDialog != null) {
			progressDialog.dismiss();
		}
	}
	
	public static ContextThemeWrapper getContextThemeWrapper(Context c) {
		if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.HONEYCOMB) {
			return new ContextThemeWrapper(c, android.R.style.Theme_Holo_Light_Dialog_NoActionBar);
		} else {
			return new ContextThemeWrapper(c, android.R.style.Theme_Light_NoTitleBar);
		}
	}

	public static String getSHACheckSum(String checksum) {
		try {
			MessageDigest md = MessageDigest.getInstance("SHA1");
			md.update(checksum.getBytes());
			byte byteData[] = md.digest();

			// convert the byte to hex format method 1
			StringBuffer sb = new StringBuffer();
			for (int i = 0; i < byteData.length; i++) {
				sb.append(Integer.toString((byteData[i] & 0xff) + 0x100, 16).substring(1));
			}
			return sb.toString();
		} catch (NoSuchAlgorithmException e) {
			e.printStackTrace();
			return null;
		}
	}

	public static boolean isJSONValid(String jsonString) {
		if (TextUtils.isEmpty(jsonString)) {
			return false;
		} else {
			try {
				new JSONObject(jsonString);
			} catch (JSONException ex) {
				return false;
			}
		}
		return true;
	}

	public static boolean canDrawOverApp(Context c) {
		if (Build.VERSION.SDK_INT >= 23) {
			try {
				Method m = Settings.class.getDeclaredMethod("canDrawOverlays", Context.class);
				m.setAccessible(true); //if security settings allow this
				Boolean o = (Boolean) m.invoke(null, c);
				return o;
			} catch (NoSuchMethodException e) {
				e.printStackTrace();
			} catch (IllegalAccessException e) {
				e.printStackTrace();
			} catch (IllegalArgumentException e) {
				e.printStackTrace();
			} catch (InvocationTargetException e) {
				e.printStackTrace();
			}
		}
		return true;
	}

	public static Bitmap drawableToBitmap(Drawable drawable) {
	    if (drawable instanceof BitmapDrawable) {
	        return ((BitmapDrawable)drawable).getBitmap();
	    }

	    int width = drawable.getIntrinsicWidth();
	    width = width > 0 ? width : 1;
	    int height = drawable.getIntrinsicHeight();
	    height = height > 0 ? height : 1;

	    Bitmap bitmap = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_8888);
	    Canvas canvas = new Canvas(bitmap); 
	    drawable.setBounds(0, 0, canvas.getWidth(), canvas.getHeight());
	    drawable.draw(canvas);

	    return bitmap;
	}
	public static boolean isOnline(Context context) {
	    ConnectivityManager cm = (ConnectivityManager) context
	            .getSystemService(Context.CONNECTIVITY_SERVICE);
	    NetworkInfo netInfo = cm.getActiveNetworkInfo();
	    return netInfo != null && netInfo.isConnectedOrConnecting();
	}
	private boolean isShowUpgrade;
	public boolean getShowUpgrade(){
		return isShowUpgrade;
	}
	public void setShowUpgrade(boolean isShowUpgrade){
		this.isShowUpgrade = isShowUpgrade;
	}
}
